{% block tags %}
{% block twitter %}
<meta name="twitter:card" content="{{ twitter_card_type }}">
<meta name="twitter:title" content="{{ object.get_meta_title }}">
<meta name="twitter:description" content="{{ object.get_meta_description }}">
{% if meta_image %}<meta name="twitter:image" content="{{ meta_image }}">{% endif %}
{% endblock twitter %}

{% block opengraph %}
<meta property="og:url" content="{{ object.get_meta_url }}">
<meta property="og:title" content="{{ object.get_meta_title }}">
<meta property="og:description" content="{{ object.get_meta_description }}">
<meta property="og:site_name" content="{{ site_name }}">
{% if meta_image %}
<meta property="og:image" content="{{ meta_image }}">
{% if meta_image_width and meta_image_height %}
<meta property="og:image:width" content="{{ meta_image_width }}">
<meta property="og:image:height" content="{{ meta_image_height }}">
{% endif %}
{% endif %}
{% endblock opengraph %}

{% block meta %}
<meta itemprop="url" content="{{ object.get_meta_url }}">
<meta itemprop="name" content="{{ object.get_meta_title }}">
<meta itemprop="description" content="{{ object.get_meta_description }}">
{% if meta_image %}<meta itemprop="image" content="{{meta_image}}">{% endif %}

<title>{{ object.get_object_title }}</title>
<meta name="description" content="{{ object.get_meta_description }}">
{% endblock meta %}
{% endblock tags %}
